==> ts-lambda-layer-0.2.10.tgz: package/index.ts <==
#!/usr/bin/env ts-node

import * as FS from "fs";
import * as Path from "path";
import * as Utility from "util";
import * as Process from "process";

const Exist = FS.existsSync;

/// Runtime Location; NPX := ~/.npm/_npx/{hash}/node_modules/{package}/index.ts
const Runtime = import.meta.url.replace("file://", "");

/// Current Working Directory
const CWD = process.cwd();

/***
 * Promisified Version of {@link FS.cp}
 * ---
 *
 * Asynchronously copies the entire directory structure from source to destination, including subdirectories and files.
 * - When copying a directory to another directory, globs are not supported.
 *
 * @experimental
 *
 * @param source {typeof import("fs").PathOrFileDescriptor} source path to copy.
 * @param target {typeof import("fs").PathOrFileDescriptor} destination path to copy to.
 * @returns {Promise<?>}
 *
 * @constructor
 *
 */

const Index = async (source, target) => {
    const $ = async () => await new Promise((resolve) => {
        FS.cp(Path.resolve(source), Path.resolve(target), {
                recursive: true,
                dereference: true,
                preserveTimestamps: false,
                errorOnExist: false,
                force: true
            }, () => resolve
        );
    })

    await $();
}

export { Index };
export default { Index };

const Arguments = Process.argv.splice(2);

const Source = (Arguments.includes("--source")) ? Arguments[Arguments.indexOf("--source") + 1] ?? null : null;
const Target = (Arguments.includes("--target")) ? Arguments[Arguments.indexOf("--target") + 1] ?? null : null;

(Target && Source) && (async () => {
    if (Exist(Source) === false) {
        throw Error("Source Directory Doesn't Exist");
    }

    await Index(Source, Target);
})();

(Target == null && Source == null) && (async () => {
    const $ = Path.resolve(CWD, Source);
    if (Exist($) === false) {
        console.warn("[Warning] Error Locating Directory Path", ":=", $);
        throw Error("Package's \"node_modules\" Directory Doesn't Exist");
    }

    const source = Path.resolve(CWD, "node_modules");
    const target = Path.resolve(CWD, "nodejs", "node_modules");

    await Index(source, target);
})();

==> ts-lambda-layer-0.2.11.tgz: package/index.ts <==
#!/usr/bin/env ts-node

import * as FS from "fs";
import * as Path from "path";
import * as Utility from "util";
import * as Process from "process";

const Exist = FS.existsSync;

/// Runtime Location; NPX := ~/.npm/_npx/{hash}/node_modules/{package}/index.ts
const Runtime = import.meta.url.replace("file://", "");

/// Current Working Directory
const CWD = () => {
    process.chdir(".");

    return process.cwd();
}

/***
 * Promisified Version of {@link FS.cp}
 * ---
 *
 * Asynchronously copies the entire directory structure from source to destination, including subdirectories and files.
 * - When copying a directory to another directory, globs are not supported.
 *
 * @experimental
 *
 * @param source {typeof import("fs").PathOrFileDescriptor} source path to copy.
 * @param target {typeof import("fs").PathOrFileDescriptor} destination path to copy to.
 * @returns {Promise<?>}
 *
 * @constructor
 *
 */

const Index = async (source, target) => {
    const $ = async () => await new Promise((resolve) => {
        FS.cp(Path.resolve(source), Path.resolve(target), {
                recursive: true,
                dereference: true,
                preserveTimestamps: false,
                errorOnExist: false,
                force: true
            }, () => resolve
        );
    })

    await $();
}

export { Index };
export default { Index };

const Arguments = Process.argv.splice(2);

const Source = (Arguments.includes("--source")) ? Arguments[Arguments.indexOf("--source") + 1] ?? null : null;
const Target = (Arguments.includes("--target")) ? Arguments[Arguments.indexOf("--target") + 1] ?? null : null;

(Target && Source) && (async () => {
    if (Exist(Source) === false) {
        throw Error("Source Directory Doesn't Exist");
    }

    await Index(Source, Target);
})();

(Target == null && Source == null) && (async () => {
    console.debug("[Debug] Runtime Path", ":=", Runtime);
    
    const $ = Path.resolve(CWD(), Source);
    if (Exist($) === false) {
        console.warn("[Warning] Error Locating Directory Path", ":=", $);
        throw Error("Package's \"node_modules\" Directory Doesn't Exist");
    }

    const source = Path.resolve(CWD(), "node_modules");
    const target = Path.resolve(CWD(), "nodejs", "node_modules");

    await Index(source, target);
})();
